================================================================
django-richtemplates -- basic Richfaces port for Django projects
================================================================

`django-richtemplates`_ is a set of templates (surprise!), template tags,
media files providing presentation layer similar to what Richfaces library
offers for J2EE developers - not outstanding but still nice looking and
elegant.

We wanted to have ability to prototype Django_ projects/applications
with some basic set of templates and thats why `django-richtemplates`_
was created. We use it for our company's intranet applications but it
can be also easily used for example projects in other Django_ pluggable
applications.

Installation
------------

Refer to ``docs/installation.rst`` file.

Documentation
-------------

Documentation is available online at
http://packages.python.org/django-richtemplates/.

Plain restructuredText
documents are located at ``docs/`` directory. You may also build *html*
version by running ``make html`` at ``docs/`` directory or ``python
setup.py build_sphinx``.

Bugs and issues
---------------

Bug and issue tracker is located at bitbucket's project page
http://bitbucket.org/lukaszb/django-richtemplates/. You may find sources
there as well.

License
-------

License should be included in LICENSE file.
Remember that `Richtemplates` make use of some third part tools. Those tools
have their own licenses.

Third part tools
----------------

1. `jQuery` - jquery_
2. `famfamfam icons` - famfamfam_

.. _jquery: http://docs.jquery.com
.. _famfamfam: http://www.famfamfam.com/archive/silk-icons-thats-your-lot/
.. _Django: http://www.djangoproject.com
.. _django-richtemplates: http://bitbucket.org/lukaszb/django-richtemplates/
